#ifndef VIEW_START_H
#define VIEW_START_H
//-----------------------------------------------------------------------------

#include "View.h"
#include <QtGui>

class Dialog;
class View_Image;

//-----------------------------------------------------------------------------
namespace Ui
{
  class View_Start;
}

//-----------------------------------------------------------------------------
class View_Start:
  public View
{
  Q_OBJECT

  public:
    View_Start(Context* a_context, QWidget* a_parent = NULL);
    ~View_Start();

  public:
    void initialize();

  public slots:
    void on_translate_clicked();
    void on_open_clicked();
    void on_camera_clicked();

    //
    //  Dialog slots ( for select a picture )
    //
    void picturePicked( const QString &picturePath );
    void dialogRejected();

 private slots:
    void
    initPicture();

  private:
    Ui::View_Start* m_ui;
    Dialog *customDialog;
    View_Image* viewImage;
    QString strFile;
};

//-----------------------------------------------------------------------------
#endif // VIEW_START_H
